<?php
namespace xenarabia\usermood\XF\Admin\Controller;

use XF\Mvc\FormAction;
use XF\Mvc\ParameterBag;
use XF\Mvc\Reply\View;
use XF\Admin\Controller\AbstractController;

use xenarabia\usermood\XF\Entity\UsermoodEntity;

class Usermood extends AbstractController{




    public function actionIndex(ParameterBag $params)
	{
		$moods = $this->getAllMoods();
		$viewParams = [
			'moods'	=> $moods
		];
		return $this->view('xenarabia\usermood\XF:usermood\view', 'usermood_view', $viewParams);
	}

    public function actionAdd()
	{
		$viewParams = [];
		return $this->view('xenarabia\usermood\XF:usermood\add', 'usermood_add', $viewParams);
    }
    
    public function actionEdit(ParameterBag $params)
	{
        $mood = $this->getMood($params['mood_id']);
		$viewParams = [
            'mood' => $mood
        ];
		return $this->view('xenarabia\usermood\XF:usermood\add', 'usermood_add', $viewParams);
    }

    public function moodEditSave(UsermoodEntity $usermoodEntity)
	{
		$entityInput = $this->filter([
            'mood_name' => 'str',
            'mood_pic' => 'str',
            'mood_act' => 'int'
            ]);

		$form = $this->formAction();
		$form->basicEntitySave($usermoodEntity, $entityInput);

		return $form;
	}

    public function actionSave(ParameterBag $params)
	{
		$this->assertPostOnly();
		if ($params['mood_id'])
		{
			$mood = $this->assertMoodExists($params['mood_id']);
			$form = $this->moodEditSave($mood);
		}
		else
		{
			$mood = $this->em()->create('xenarabia\usermood\XF:UsermoodEntity');
			$form = $this->moodEditSave($mood);
		}

		
		if(get_class($form) === 'XF\Mvc\Reply\Error') {
			return $form;
		} else {
			$form->run();
		}

		return $this->redirect($this->buildLink('usermood'), \XF::phrase('mood_has_been_posted'));
	}
    
    public function actionDelete(ParameterBag $params)
	{
		$mood = $this->assertMoodExists($params['mood_id']);
		
		
		/** @var \XF\ControllerPlugin\Delete $plugin */
		$plugin = $this->plugin('XF:Delete');
		return $plugin->actionDelete(
			$mood,
			$this->buildLink('usermood/delete', $mood),
			$this->buildLink('usermood/edit', $mood),
			$this->buildLink('usermood'),			
			$mood->mood_name
		);
	}


    protected function assertMoodExists($id, $with = null, $phraseKey = null)
	{
		return $this->assertRecordExists('xenarabia\usermood\XF:UsermoodEntity', $id, $with, $phraseKey);
	}

    public function getAllMoods()
    {
        $repo = $this->repository('xenarabia\usermood\XF:UsermoodRepo');
		return $repo->getUsermood();
    }
    
    

    public function getMood($mood_id)
    {
        $repo = $this->repository('xenarabia\usermood\XF:UsermoodRepo');
		return $repo->getUsermoodById($mood_id);
	}
}